@@ -27,11 +27,9 @@ sub requires {
 ##  if ( ! $self->distribution() ) {
 ##  }
     return {
-	'Carp'			=> 0,
-	'HTTP::Request::Common'	=> 0,
-	'LWP::UserAgent'	=> 0,
-	'Scalar::Util'		=> 1.10,
-	'XML::Parser'		=> 0,
+	'Params::Util'	=> 0.11,
+	'Scalar::Util'	=> 1.10,
+	'SOAP::Lite'	=> 0,
 	@extra,
     };
 }
