@@ -82,6 +82,8 @@ The following public methods are provided:
 
 package Geo::WebService::Elevation::USGS;
 
+use 5.008;
+
 use strict;
 use warnings;
 
@@ -90,10 +92,42 @@ use Params::Util 0.11 qw{_INSTANCE};
 use Scalar::Util 1.10 qw{looks_like_number};
 use SOAP::Lite;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use constant BEST_DATA_SET => -1;
 
+my $using_time_hires;
+{
+    our $THROTTLE;
+    my $mark;
+    if ( eval {
+	    require Time::HiRes;
+	    Time::HiRes->can( 'time' ) && Time::HiRes->can( 'sleep' );
+	} ) {
+	*_time = \&Time::HiRes::time;
+	*_sleep = \&Time::HiRes::sleep;
+	$using_time_hires = 1;
+    } else {
+	*_time = sub { return time };
+	*_sleep = sub { return sleep $_[0] };
+    }
+
+    $mark = _time();
+    sub _pause {
+	my ( $self ) = @_;
+	defined $THROTTLE
+	    and croak '$THROTTLE revoked - use ', __PACKAGE__,
+		'->set( throttle => value ) instead';
+	my $now = _time();
+	while ( $now < $mark ) {
+	    _sleep( $mark - $now );
+	    $now = _time();
+	}
+	$mark = $now + __PACKAGE__->get( 'throttle' );
+	return;
+    }
+}
+
 =head3 $eq = Geo::WebService::Elevation::USGS->new();
 
 This method instantiates a query object. If any arguments are given,
@@ -108,12 +142,15 @@ sub new {
     $class or croak "No class name specified";
     shift;
     my $self = {
+	carp	=> 0,
 	croak	=> 1,
 	default_ns	=> 'http://gisdata.usgs.gov/XMLWebServices2/',
 	error	=> undef,
 	places	=> undef,
 	proxy	=>
 	    'http://gisdata.usgs.gov/xmlwebservices2/elevation_service.asmx',
+	retry	=> 0,
+	retry_hook => sub {},
 	source	=> BEST_DATA_SET,
 	timeout	=> 30,
 	trace	=> undef,
@@ -127,17 +164,30 @@ sub new {
 
 my %mutator = (
     croak	=> \&_set_literal,
+    carp	=> \&_set_literal,
     default_ns	=> \&_set_literal,
-    error	=> \&_set_literal,,
+    error	=> \&_set_literal,
     places	=> \&_set_integer_or_undef,
     proxy	=> \&_set_literal,
+    retry	=> \&_set_unsigned_integer,
+    retry_hook	=> \&_set_hook,
     source	=> \&_set_source,
+    throttle	=> \&_set_throttle,
     timeout	=> \&_set_integer_or_undef,
     trace	=> \&_set_literal,
     units	=> \&_set_literal,
     use_all_limit => \&_set_use_all_limit,
 );
 
+my %access_type = (
+    throttle	=> \&_only_static_attr,
+);
+
+foreach my $name ( keys %mutator ) {
+    exists $access_type{$name}
+	or $access_type{$name} = \&_no_static_attr;
+}
+
 =head3 %values = $eq->attributes();
 
 This method returns a list of the names and values of all attributes of
@@ -230,9 +280,9 @@ therefore has the same result as
 
  $ele->set(source => qr{CONUS}i);
 
-If the optional $valid argument to elevation() is specified, data with
-invalid elevations are eliminated before the array is returned. Note
-that this may result in an empty array.
+If the optional C<$valid> argument to elevation() is specified, data
+with invalid elevations are eliminated before the array is returned.
+Note that this may result in an empty array.
 
 =cut
 
@@ -252,12 +302,10 @@ that this may result in an empty array.
     );
 
     sub elevation {
-	my @args = @_;
-	my ($self, $lat, $lon, $valid) = _latlon(@args);
+	my ($self, $lat, $lon, $valid) = _latlon( @_ );
 	my $ref = ref (my $source = $self->_get_source());
 	my $rslt;
 	if ($ref eq 'ARRAY') {
-####	    $self->_supress_no_value_err(\$ref);
 	    $rslt = [];
 	    foreach (@$source) {
 		push @$rslt, $self->getElevation($lat, $lon, $_);
@@ -272,9 +320,8 @@ that this may result in an empty array.
 	    $rslt = [grep {$check->($self, $source, $_)} @$raw];
   	    if ($ref eq 'HASH') {
 		foreach (sort keys %$source) {
-		    my $err = "Source Data_ID $_ not found";
-		    $self->get('croak') and croak $err;
-		    $self->set(error => $err);
+		    $self->_error( "Source Data_ID $_ not found" );
+		    $self->{croak} and croak $self->{error};
 		    return;
 		}
 	    }
@@ -299,13 +346,14 @@ the attribute does not exist.
 =cut
 
 sub get {
-    my ($self, $attr) = @_;
-    exists $mutator{$attr}
-	or croak "No such attribute as '$attr'";
-    return $self->{$attr};
+    my ($self, $name) = @_;
+    $access_type{$name}
+	or croak "No such attribute as '$name'";
+    my $holder = $access_type{$name}->( $self, $name );
+    return $holder->{$name};
 }
 
-=head3 $rslt = $eq->getAllElevations($lat, $lon);
+=head3 $rslt = $eq->getAllElevations($lat, $lon, $valid);
 
 This method executes the getAllElevations query, which returns the
 elevation of the given point as recorded in all available data sets. The
@@ -326,47 +374,76 @@ non-numeric value (e.g. 'BAD_EXTENT', though this is nowhere documented
 that I can find), or a very large negative number (documented as
 -1.79769313486231E+308).
 
+If the optional C<$valid> argument to getAllElevations() is specified,
+data with invalid elevations are eliminated before the array is
+returned. Note that this may result in an empty array.
+
 =cut
 
 sub getAllElevations {
-    my @args = @_;
-    my ($self, $lat, $lon) = _latlon(@args);
+    my ($self, $lat, $lon, $valid) = _latlon( @_ );
     my $soap = $self->_soapdish();
+    my $retry_limit = $self->get( 'retry' );
+    my $retry = 0;
 
-    my $raw = exists $self->{_hack_result} ?
-	delete $self->{_hack_result} :
-	eval {
-	$soap->call (SOAP::Data->name ('getAllElevations')->attr (
-		{xmlns => $self->{default_ns}}) =>
-	    SOAP::Data->new(name => 'X_Value', type => 'string',
-		value => $lon),
-	    SOAP::Data->new(name => 'Y_Value', type => 'string',
-		value => $lat),
-	    SOAP::Data->new(name => 'Elevation_Units', type => 'string',
-		value => $self->{units}),
-	);
-    };
-    my $cooked = $self->_digest($raw);
-    ref $cooked eq 'HASH' or return;
-    my @rslt;
-    my $ref = ref $cooked->{Data_ID};
-    if ($ref eq 'ARRAY') {
-	my $limit = @{$cooked->{Data_ID}} - 1;
-	foreach my $inx (0 .. (scalar @{$cooked->{Data_ID}} - 1)) {
-	    push @rslt, {
-		Data_Source => $cooked->{Data_Source}[$inx],
-		Data_ID => $cooked->{Data_ID}[$inx],
-		Elevation => $cooked->{Elevation}[$inx],
-		Units => $cooked->{Units}[$inx],
+    while ( $retry++ <= $retry_limit ) {
+
+	$self->{error} = undef;
+	eval {1};	# Clear $@.
+
+	$self->_pause();
+
+	my $raw = exists $self->{_hack_result} ?
+	    delete $self->{_hack_result} :
+	    eval {
+
+		local $SOAP::Constants::DO_NOT_USE_CHARSET = 1;
+
+		$soap->call (SOAP::Data->name ('getAllElevations')->attr (
+			{xmlns => $self->{default_ns}}) =>
+		    SOAP::Data->new(name => 'X_Value', type => 'string',
+			value => $lon),
+		    SOAP::Data->new(name => 'Y_Value', type => 'string',
+			value => $lat),
+		    SOAP::Data->new(name => 'Elevation_Units', type => 'string',
+			value => $self->{units}),
+		);
 	    };
+	my $cooked = $self->_digest($raw);
+	ref $cooked eq 'HASH' or next;
+	my @rslt;
+	my $ref = ref $cooked->{Data_ID};
+	if ($ref eq 'ARRAY') {
+	    my $limit = @{$cooked->{Data_ID}} - 1;
+	    foreach my $inx (0 .. (scalar @{$cooked->{Data_ID}} - 1)) {
+		push @rslt, {
+		    Data_Source => $cooked->{Data_Source}[$inx],
+		    Data_ID => $cooked->{Data_ID}[$inx],
+		    Elevation => $cooked->{Elevation}[$inx],
+		    Units => $cooked->{Units}[$inx],
+		};
+	    }
+	} elsif ($ref) {
+	    $self->_error( "Unexpected $ref reference in {Data_ID}" );
+	    next;
+	} else {	# One of the ActiveState MSWin32 variants seems to do this.
+	    push @rslt, $cooked;
 	}
-    } elsif ($ref) {
-	return $self->_error(
-	    "Unexpected $ref reference in {Data_ID}");
-    } else {	# One of the ActiveState MSWin32 variants seems to do this.
-	push @rslt, $cooked;
+	if ($valid) {
+	    @rslt = grep {is_valid($_)} @rslt;
+	}
+	return \@rslt;
+
+    } continue {
+
+	$retry <= $retry_limit
+	    and $self->get( 'retry_hook' )->( $self, $retry,
+	    getAllElevations => $lat, $lon );
+
     }
-    return \@rslt;
+
+    $self->{croak} and croak $self->{error};
+    return;
 }
 
 =head3 $rslt = $eq->getElevation($lat, $lon, $source, $elevation_only);
@@ -439,40 +516,67 @@ about it.
 =cut
 
 sub getElevation {
-    my @args = @_;
-    my ($self, $lat, $lon, $source, $only) = _latlon(@args);
+    my ($self, $lat, $lon, $source, $only) = _latlon( @_ );
     defined $source or $source = BEST_DATA_SET;
     my $soap = $self->_soapdish();
+    my $retry_limit = $self->get( 'retry' );
+    my $retry = 0;
 
-    my $rslt = exists $self->{_hack_result} ?
-	delete $self->{_hack_result} :
-	eval {
-	$soap->call(SOAP::Data->name ('getElevation')->attr (
-		{xmlns => $self->{default_ns}}) =>
-	    SOAP::Data->new(name => 'X_Value', type => 'string',
-		value => $lon),
-	    SOAP::Data->new(name => 'Y_Value', type => 'string',
-		value => $lat),
-	    SOAP::Data->new(name => 'Source_Layer', type => 'string', 
-		value => $source),
-	    SOAP::Data->new(name => 'Elevation_Units', type => 'string',
-		value => $self->{units}),
-	    SOAP::Data->new(name => 'Elevation_Only', type => 'string',
-		value => $only ? 'true' : 'false'),
-	);
-    };
+    while ( $retry++ <= $retry_limit ) {
 
-    $@ and return $self->_digest($rslt, $source);
+	$self->{error} = undef;
+	eval {1};	# Clear $@.
 
-    if (_INSTANCE($rslt, 'SOAP::SOM') && $rslt->fault &&
-	    $rslt->faultstring =~
-	m/Conversion from string "BAD_EXTENT" to type 'Double'/) {
-	if (my $hash = $self->_get_bad_extent_hash($source)) {
-	    return $hash;
+	$self->_pause();
+
+	my $rslt = exists $self->{_hack_result} ?
+	    delete $self->{_hack_result} :
+	    eval {
+
+		local $SOAP::Constants::DO_NOT_USE_CHARSET = 1;
+
+		$soap->call(SOAP::Data->name ('getElevation')->attr (
+			{xmlns => $self->{default_ns}}) =>
+		    SOAP::Data->new(name => 'X_Value', type => 'string',
+			value => $lon),
+		    SOAP::Data->new(name => 'Y_Value', type => 'string',
+			value => $lat),
+		    SOAP::Data->new(name => 'Source_Layer', type => 'string', 
+			value => $source),
+		    SOAP::Data->new(name => 'Elevation_Units', type => 'string',
+			value => $self->{units}),
+		    SOAP::Data->new(name => 'Elevation_Only', type => 'string',
+			value => $only ? 'true' : 'false'),
+		);
+	    };
+
+	$@ and do {
+	    $self->_error( $@ );
+	    next;
+	};
+
+	if (_INSTANCE($rslt, 'SOAP::SOM') && $rslt->fault &&
+		$rslt->faultstring =~
+	    m/Conversion from string "BAD_EXTENT" to type 'Double'/) {
+	    if (my $hash = $self->_get_bad_extent_hash($source)) {
+		return $hash;
+	    }
 	}
+
+	my $info = $self->_digest( $rslt, $source ) or next;
+	return $info;
+
+    } continue {
+
+	$retry <= $retry_limit
+	    and $self->get( 'retry_hook' )->( $self, $retry,
+	    getElevation => $lat, $lon, $source, $only );
+
     }
 
-    return $self->_digest($rslt, $source);
+    $self->{croak} and croak $self->{error};
+    return;
+
 }
 
 =head3 $boolean = $eq->is_valid($elevation);
@@ -505,27 +609,52 @@ result in an exception being thrown.
 
 =cut
 
-sub set {
-    my ($self, @args) = @_;
-    while (@args) {
-	my $attr = shift @args;
-	exists $mutator{$attr}
-	    or croak "No such attribute as '$attr'";
-	$mutator{$attr}->($self, $attr, shift @args);
+
+{
+
+    my %clean_soapdish;	# Attributes that are used in _soapdish();
+
+    sub set {
+	my ($self, @args) = @_;
+	my $clean;
+	while (@args) {
+	    my ( $name, $val ) = splice @args, 0, 2;
+	    $access_type{$name}
+		or croak "No such attribute as '$name'";
+	    exists $mutator{$name}
+		or croak "Attribute '$name' is read-only";
+	    my $holder = $access_type{$name}->( $self, $name );
+	    $mutator{$name}->( $holder, $name, $val );
+	    $clean ||= $clean_soapdish{$name};
+	}
+	$clean and delete $self->{_soapdish};
+	return $self;
     }
-    return $self;
+
+    sub _set_clean_soapdish {
+	%clean_soapdish = map { $_ => 1 } @_;
+	return;
+    }
+
+}
+
+sub _set_hook {
+    my ( $self, $name, $val ) = @_;
+    ref $val eq 'CODE'
+	or croak "Attribute $name must be a code reference";
+    return( $self->{$name} = $val );
 }
 
 sub _set_integer {
     my ($self, $name, $val) = @_;
-    (!defined $val || $val !~ m/^[-+]?\d+$/)
+    (!defined $val || $val !~ m/ \A [-+]? \d+ \z /smx)
 	and croak "Attribute $name must be an integer";
     return ($self->{$name} = $val + 0);
 }
 
 sub _set_integer_or_undef {
     my ($self, $name, $val) = @_;
-    (defined $val && $val !~ m/^\d+$/)
+    (defined $val && $val !~ m/ \A \d+ \z /smx)
 	and croak "Attribute $name must be an unsigned integer or undef";
     return ($self->{$name} = $val);
 }
@@ -546,6 +675,30 @@ sub _set_literal {
     }
 }
 
+sub _set_throttle {
+    my ( $self, $name, $val ) = @_;
+    if ( defined $val ) {
+	looks_like_number( $val )
+	    and $val >= 0
+	    or croak "The $name attribute must be undef or a ",
+		'non-negative number';
+	$using_time_hires
+	    or $val >= 1
+	    or $val == 0
+	    or $val = 1;
+    } else {
+	$val = 0;
+    }
+    return( $self->{$name} = $val );
+}
+
+sub _set_unsigned_integer {
+    my ($self, $name, $val) = @_;
+    ( !defined $val || $val !~ m/ \A \d+ \z /smx )
+	and croak "Attribute $name must be an unsigned integer";
+    return ($self->{$name} = $val + 0);
+}
+
 sub _set_use_all_limit {
     _set_integer(@_);
     delete $_[0]{_source_cache};
@@ -591,6 +744,8 @@ sub _digest {
 		: $_[0]}
 	}
     }
+
+    my $error;
     if (ref $rslt eq 'HASH') {
 	# The following line is because we may be handling an 'elevation
 	# only' request.
@@ -601,30 +756,29 @@ sub _digest {
 	foreach my $key (
 	    qw{USGS_Elevation_Web_Service_Query Elevation_Query}) {
 	    (ref $rslt eq 'HASH' && exists $rslt->{$key}) or do {
-		$self->{error} = "Elevation result is missing tag <$key>";
+		$error = "Elevation result is missing tag <$key>";
 		last;
 	    };
 	    $rslt = $rslt->{$key};
 	}
 	unless (ref $rslt) {
 	    if (defined $source &&
-####		$self->_supress_no_value_err() &&
-		$rslt =~ m/ERROR:\sNo\sElevation\svalue\swas\sreturned\s
-			from\sservers\./ix &&
+		$rslt =~ m/ \b ERROR: [ ] No [ ] Elevation [ ] value [ ]
+		    was [ ] returned [ ] from [ ] server /ismx &&
 		(my $hash = $self->_get_bad_extent_hash($source))) {
 		return $hash;
 	    }
-	    $rslt =~ m/[.?!]$/ or $rslt .= '.';
-	    $self->{error} = defined $source ?
+	    $rslt =~ m/ [.?!] \z /smx or $rslt .= '.';
+	    $error = defined $source ?
 		"$rslt Source = '$source'" : $rslt;
 	}
     } else {
-	$self->{error} = "No data found in SOAP result";
-    }
-    if ($self->{error}) {
-	$self->{croak} and croak $self->{error};
-	return;
+	$error = "No data found in SOAP result";
     }
+
+    $error
+	and return $self->_error( $error );
+
     if ($rslt && $round) {
 	if (ref $rslt->{Elevation}) {
 	    $rslt->{Elevation} = [
@@ -639,12 +793,15 @@ sub _digest {
 #	$ele->_error($text);
 #
 #	Set the error attribute, and croak if the croak attribute is
-#	true. If croak is false, just return.
+#	true. If croak is false, just return, carping if the carp
+#	attribute is true.
 
 sub _error {
     my ($self, @args) = @_;
     $self->{error} = join '', @args;
-    $self->{croak} and croak $self->{error};
+##  $self->{croak} and croak $self->{error};
+    $self->{croak} and return;
+    $self->{carp} and carp $self->{error};
     return;
 }
 
@@ -787,6 +944,39 @@ sub _get_source_cache {
     }
 }
 
+{
+    my %static = (	# Static attribute values.
+	throttle => 0,
+    );
+
+#	$self->_no_static_attr( $name );
+#
+#	Croaks if the invocant is not a reference. The message assumes
+#	the method was called trying to access an attribute, whose name
+#	is $name.
+
+    sub _no_static_attr {
+	my ( $self, $name ) = @_;
+	ref $self
+	    or croak "Attribute $name may not be accessed statically";
+	return $self;
+    }
+
+#	$self->_only_static_attr( $name );
+#
+#	Croaks if the invocant is a reference. The message assumes the
+#	method was called trying to access an attribute, whose name is
+#	$name.
+
+    sub _only_static_attr {
+	my ( $self, $name ) = @_;
+	ref $self
+	    and croak "Attribute $name may only be accessed statically";
+	return \%static;
+    }
+
+}
+
 #	$id = _normalize_id($id)
 #
 #	This subroutine normalizes a Source_ID by uppercasing it. It
@@ -804,12 +994,14 @@ sub _normalize_id {return uc $_[0]}
 #	We also set the error attribute and $@ to undef in preparation
 #	for a query.
 
+_set_clean_soapdish( qw{ default_ns proxy timeout } );
+
 sub _soapdish {
     my $self = shift;
+    $self->{trace} and SOAP::Trace->import ('all');
+    $self->{_soapdish} and return $self->{_soapdish};
     my $conn = '';	# Other possibility is '#'.
     my $act = sub {join $conn, @_};
-    $self->{error} = undef;
-    $self->{trace} and SOAP::Trace->import ('all');
     my $soap = SOAP::Lite->can ('default_ns') ?
 	SOAP::Lite
 	    ->default_ns ($self->{default_ns})
@@ -820,46 +1012,9 @@ sub _soapdish {
 	    ->on_action ($act)
 	    ->uri ($self->{default_ns})
 	    ->proxy ($self->{proxy}, timeout => $self->{timeout});
-    eval {1};	# Clear $@.
-    return $soap;
+    return ( $self->{_soapdish} = $soap );
 }
 
-#	$boolean = $ele->_supress_no_value_err()
-#	or
-#	$boolean = $ele->_supress_no_value_err($value);
-#
-#	This method returns (and optionally sets) an internal attribute
-#	that causes the _digest method to return a packet with an
-#	elevation of 'BAD_EXTENT' rather than an error when it
-#	determines that getElevation has in fact encountered a bad
-#	extent.
-#
-#	If the $value is a reference, it is weakened after it is stored,
-#	which causes the internal attribute to magically become unset
-#	when the referenced variable goes out of scope.
-
-=begin comment
-
-die <<eod;
-This code requires 'weaken', which in turn requires version 1.14 of
-Scalar::Util. Without this code, Scalar::Util is unconstrained.
-Obviously, this 'die' must be removed.
-eod
-
-sub _supress_no_value_err {
-    my ($self, @args) = @_;
-    if (@args) {
-	my $value = $args[0];
-	$self->{_supress_no_value_err} = $value;
-	ref $value and weaken $self->{_supress_no_value_err};
-    }
-    return $self->{_supress_no_value_err};
-}
-
-=end comment
-
-=cut
-
 
 1;
 
@@ -867,11 +1022,29 @@ __END__
 
 =head2 Attributes
 
+=head3 carp (boolean)
+
+This boolean attribute determines whether the data acquisition methods carp on
+encountering an error. If false, they silently return undef. Note,
+though, that the L<croak|/croak> attribute trumps this one.
+
+If L<retry|/retry> is set to a number greater than 0, you will get a
+carp on each failed query, provided L<croak|/croak> is false. If
+L<croak|/croak> is true, no retries will be carped.
+
+This attribute was introduced in Geo::WebService::Elevation::USGS
+version 0.005_01.
+
+The default is 0 (i.e. false).
+
 =head3 croak (boolean)
 
 This attribute determines whether the data acquisition methods croak on
 encountering an error. If false, they return undef on an error.
 
+If L<retry|/retry> is set to a number greater than 0, the data
+acquisition method will not croak until all retries are exhausted.
+
 The default is 1 (i.e. true).
 
 =head3 default_ns (string)
@@ -920,6 +1093,43 @@ track the change.
 The default is
 'http://gisdata.usgs.gov/xmlwebservices2/elevation_service.asmx'.
 
+=head3 retry (unsigned integer)
+
+This attribute specifies the number of retries to be done by
+C<getAllElevations()> and C<getElevation()> when an error is
+encountered. The first try is not considered a retry, so if you set this
+to 1 you get a maximum of two queries (the try and the retry).
+
+Retries are done only on actual errors, not on bad extents. They are
+also subject to the L</throttle> setting if any.
+
+The default is 0, i.e. no retries.
+
+=head3 retry_hook (code reference)
+
+This attribute specifies a piece of code to be called before retrying.
+The code will be called before a retry takes place, and will be passed
+the Geo::WebService::Elevation::USGS object, the number of the retry
+(from 1), the name of the method being retried (C<'getAllElevations'> or
+C<'getElevation'>), and the arguments to that method. If the position
+was passed as an object, the hook gets the latitude and longitude
+unpacked from the object. The hook will B<not> be called before the
+first try, nor after the last retry.
+
+Examples:
+
+ # To sleep 5 seconds between retries:
+ $eq->set( retry_hook => sub { sleep 5 } );
+ 
+ # To sleep 1 second before the first retry, 2 seconds
+ # before the second, and so on:
+ $eq->set( retry_hook => sub { sleep $_[1] } );
+ 
+ # To do nothing between retries:
+ $eq->set( retry_hook => sub {} );
+
+The default is the null subroutine, i.e. C<sub {}>.
+
 =head3 source
 
 This attribute specifies the ID of the source layer to be queried by
@@ -933,6 +1143,20 @@ used.
 The default is '-1', which requests a response from the 'best' data
 source for the given point.
 
+=head3 throttle (non-negative number, or undef)
+
+ Geo::WebService::Elevation::USGS->set( throttle => 5 );
+
+This attribute, if defined and positive, specifies the minimum interval
+between queries, in seconds. This attribute may be set statically only,
+and the limit applies to all queries, not just the ones from a given
+object. If L<Time::HiRes|Time::HiRes> can be loaded, then sub-second
+intervals are supported, otherwise not.
+
+This functionality, and its implementation, are experimental, and may be
+changed or retracted without notice. Heck, I may even go back to
+C<$TARGET>, though I don't think so.
+
 =head3 timeout (integer, or undef)
 
 This attribute specifies the timeout for the SOAP query in seconds.
@@ -974,6 +1198,39 @@ entries at all, no matter how many it has.
 
 The default is 5, which was chosen based on timings of the two methods.
 
+=head2 Globals
+
+=head3 $Geo::WebService::Elevation:USGS::THROTTLE
+
+B<This interface is deprecated;> use the L</throttle> static method
+instead. It will be revoked in release C<0.006>, and at that time
+setting C<$THROTTLE> will become a fatal error. The short deprecation
+cycle is because this interface has never been released in a production
+release, and because you were warned when it was introduced. Until the
+next production release, the next query after setting C<$THROTTLE> will
+cause a warning message to be issued, and its value to be passed to
+L</throttle>.
+
+If set to a positive number, this symbol limits the rate at which
+queries can be issued. The value represents the minimum interval between
+queries (in seconds), which is enforced by having the query methods
+C<sleep()> as needed. This minimum is enforced among objects, not just
+within a single object.
+
+If L<Time::HiRes|Time::HiRes> can be loaded, its C<time()> and
+C<sleep()> will be used, and fractional minimum intervals can be
+specified. If it can not be loaded, the core C<time()> and C<sleep()>
+will be used. With the core functions, the resolution is a second, and
+a C<$THROTTLE> value between 0 and 1 will be taken to be 1.
+
+The behavior of this functionality when C<$THROTTLE> is set to a
+non-numeric value is undefined. In practice, you will probably get an
+error of some sort when you issue the query, but the author makes no
+commitments. Same for quasi-numbers such as C<Inf> and C<NaN>.
+
+The default is C<undef>, which means that this functionality is
+disabled.
+
 =head1 ACKNOWLEDGMENTS
 
 The author wishes to acknowledge the following individuals and groups.
@@ -996,14 +1253,18 @@ L<http://rt.cpan.org/>.
 
 Thomas R. Wyant, III; F<wyant at cpan dot org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008, 2009 by Thomas R. Wyant, III. All rights reserved.
+Copyright (C) 2008-2010, Thomas R. Wyant, III
 
-=head1 LICENSE
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl 5.10.0. For more details, see the full text
+of the licenses in the directory LICENSES.
 
-This module is free software; you can use it, redistribute it and/or
-modify it under the same terms as Perl itself. Please see
-L<http://perldoc.perl.org/index-licence.html> for the current licenses.
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =cut
+
+# ex: set textwidth=72 :
